@@ -47,7 +47,7 @@ class ExperimentCollection(object):
 
 class Experiment(object):
 
-    def __init__(self, name, alternatives, redis_conn):
+    def __init__(self, name, alternatives, redis_conn, version=None):
         if len(alternatives) < 2:
             raise ValueError('experiments require at least two alternatives')
 
@@ -55,6 +55,7 @@ class Experiment(object):
         self.redis = redis_conn
         self.random_sample = RANDOM_SAMPLE
         self.alternatives = self.initialize_alternatives(alternatives)
+        self._version = version
 
     def __repr__(self):
         return '<Experiment: {0} (version: {1})>'.format(self.name, self.version())
@@ -74,9 +75,6 @@ class Experiment(object):
             # Set version to zero
             pipe.set(_key("experiments:{0}".format(self.name)), 0)
 
-            # Empty desc by default
-            pipe.hset(self.key(), 'description', '')
-
         pipe.hset(self.key(), 'created_at', datetime.now())
         # reverse here and use lpush to keep consistent with using lrange
         for alternative in reversed(self.alternatives):
@@ -129,20 +127,27 @@ class Experiment(object):
         if stat_range not in ['days', 'months', 'years']:
             raise ValueError
 
-        stats = {}
+        pipe = self.redis.pipe()
 
+        stats = {}
         search_key = _key("{0}:{1}:{2}".format(stat_type, self.rawkey(), stat_range))
         keys = self.redis.smembers(search_key)
         for k in keys:
             mod = '' if stat_type == 'participations' else "users:"
             range_key = _key("{0}:{1}:_all:{2}{3}".format(stat_type, self.rawkey(), mod, k))
-            print range_key
-            stats[k] = self.redis.bitcount(range_key)
+            pipe.bitcount(range_key)
+
+        redis_results = pipe.execute()
+        for idx, k in enumerate(keys):
+            stats[k] = redis_results[idx]
 
         return stats
 
     def update_description(self, description=None):
-        self.redis.hset(self.key(), 'description', description or '')
+        if description == '' or description is None:
+            self.redis.hdel(self.key(), 'description')
+        else:
+            self.redis.hset(self.key(), 'description', description)
 
     def get_description(self):
         return self.redis.hget(self.key(), 'description')
@@ -176,7 +181,14 @@ class Experiment(object):
     def is_archived(self):
         return self.redis.hexists(self.key(), 'archived')
 
+    def versions(self):
+        current_version = self.version()
+        return range(0, (current_version + 1))
+
     def version(self):
+        if self._version is not None:
+            return self._version
+
         version = self.redis.get(_key("experiments:{0}".format(self.name)))
         return int(version) if version else 0
 
@@ -285,9 +297,9 @@ class Experiment(object):
         return _key(key)
 
     @classmethod
-    def find(cls, experiment_name, redis_conn):
+    def find(cls, experiment_name, redis_conn, version=None):
         if redis_conn.sismember(_key("experiments"), experiment_name):
-            return cls(experiment_name, Experiment.load_alternatives(experiment_name, redis_conn), redis_conn)
+            return cls(experiment_name, Experiment.load_alternatives(experiment_name, redis_conn, version), redis_conn, version)
         else:
             raise ValueError('experiment does not exist')
 
@@ -337,9 +349,10 @@ class Experiment(object):
         return experiments
 
     @staticmethod
-    def load_alternatives(experiment_name, redis_conn):
+    def load_alternatives(experiment_name, redis_conn, version=None):
         # get latest version of experiment
-        version = redis_conn.get(_key("experiments:{0}".format(experiment_name)))
+        if version is None:
+            version = redis_conn.get(_key("experiments:{0}".format(experiment_name)))
         key = _key("experiments:{0}/{1}:alternatives".format(experiment_name, version))
         return redis_conn.lrange(key, 0, -1)
 
@@ -418,19 +431,29 @@ class Alternative(object):
 
         stats = {}
 
+        pipe = self.redis.pipeline()
+
         exp_key = self.experiment.rawkey()
         search_key = _key("{0}:{1}:{2}".format(stat_type, exp_key, stat_range))
+
         keys = self.redis.smembers(search_key)
         for k in keys:
             name = self.name if stat_type == 'participations' else "{0}:users".format(self.name)
             range_key = _key("{0}:{1}:{2}:{3}".format(stat_type, exp_key, name, k))
-            stats[k] = self.redis.bitcount(range_key)
+            pipe.bitcount(range_key)
+
+        redis_results = pipe.execute()
+        for idx, k in enumerate(keys):
+            stats[k] = redis_results[idx]
 
         return stats
 
-    def record_participation(self, client):
+    def record_participation(self, client, dt=None):
         """Record a user's participation in a test along with a given variation"""
-        date = datetime.now()
+        if dt is None:
+            date = datetime.now()
+        else:
+            date = dt
 
         experiment_key = self.experiment.rawkey()
 
@@ -454,9 +477,13 @@ class Alternative(object):
         ]
         msetbit(keys=keys, args=([client.sequential_id, 1] * len(keys)))
 
-    def record_conversion(self, client):
+    def record_conversion(self, client, dt=None):
         """Record a user's conversion in a test along with a given variation"""
-        date = datetime.now()
+        if dt is None:
+            date = datetime.now()
+        else:
+            date = dt
+
         experiment_key = self.experiment.rawkey()
 
         pipe = self.redis.pipeline()
