@@ -1,5 +1,6 @@
 from flask import Flask, render_template, abort, request, url_for, redirect
 from flask.ext.seasurf import SeaSurf
+from flask_debugtoolbar import DebugToolbarExtension
 
 from config import CONFIG as cfg
 from db import REDIS
@@ -9,12 +10,16 @@ import utils
 app = Flask(__name__)
 csrf = SeaSurf(app)
 
+app.debug = True
 
 # List of experiments
 @app.route("/")
 def hello():
-    experiments = Experiment.all(REDIS)
-    return render_template('dashboard.html', experiments=experiments)
+    archived = bool(request.args.get('include_archived', False))
+    exclude_archived = not archived
+    experiments = Experiment.all(REDIS, exclude_archived)
+
+    return render_template('dashboard.html', experiments=experiments, include_archived=archived)
 
 
 # Details for experiment
@@ -88,7 +93,7 @@ def favicon():
 
 def find_or_404(experiment_name):
     try:
-        return Experiment.find(experiment_name, REDIS)
+        return Experiment.find(experiment_name, REDIS, request.args.get('version', None))
     except:
         abort(404)
 
@@ -96,7 +101,7 @@ def find_or_404(experiment_name):
 app.secret_key = cfg.get('secret_key')
 app.jinja_env.filters['number_to_percent'] = utils.number_to_percent
 app.jinja_env.filters['number_format'] = utils.number_format
-
+toolbar = DebugToolbarExtension(app)
 
 def start(environ, start_response):
     return app(environ, start_response)
